@@ -4,14 +4,14 @@ use strict;
 use warnings;
 use Carp;
 
-our $VERSION = '2.02'; # VERSION
+our $VERSION = '2.04'; # VERSION
 
 use parent 'Exporter';
 use Test::Builder;
 use version 0.86 qw( is_lax is_strict );
 use File::Find::Rule::Perl;
 use Test::More;
-use Module::Metadata;
+use Module::Metadata 1.000019;
 
 our @EXPORT = qw( version_all_ok ); ## no critic (Modules::ProhibitAutomaticExportation)
 our @EXPORT_OK = qw( version_ok );
@@ -73,6 +73,8 @@ my %versions;
 
 my $test = Test::Builder->new;
 
+our $_IN_VERSION_ALL_OK = 0;
+
 sub version_ok {
   my ( $file, $name ) = @_;
   $file ||= '';
@@ -116,7 +118,7 @@ sub version_ok {
   my @diag;
   my @packages = $cfg->{multiple} ? $info->packages_inside : ($info->name);
 
-  unless( (caller(1))[3] eq 'Test::Version::version_all_ok') {
+  unless($_IN_VERSION_ALL_OK) {
     $consistent = 1;
     $version_number  = undef;
   }
@@ -176,7 +178,7 @@ sub version_ok {
     }
   }
 
-  unless( (caller(1))[3] eq 'Test::Version::version_all_ok') {
+  unless($_IN_VERSION_ALL_OK) {
     if($ok && ! $consistent && $cfg->{consistent}) {
       $ok = 0;
       push @diag, "The versions found in '$file' are inconsistent.";
@@ -211,8 +213,11 @@ sub version_all_ok {
 
   my @files = File::Find::Rule->perl_module->in( $dir );
 
-  foreach my $file ( @files ) {
-    version_ok( $file );
+  {
+    local $_IN_VERSION_ALL_OK = 1;
+    foreach my $file ( @files ) {
+      version_ok( $file );
+    }
   }
 
   if ($cfg->{consistent} and not $consistent) {
@@ -257,7 +262,7 @@ Test::Version - Check to see that version's in modules are sane
 
 =head1 VERSION
 
-version 2.02
+version 2.04
 
 =head1 SYNOPSIS
 
@@ -425,12 +430,16 @@ feature.
 
 =head1 CONTRIBUTORS
 
-=for stopwords Gabor Szabo Karen Etheridge Michael G. Schwern Mike Doherty particle
+=for stopwords Dave Rolsky Gabor Szabo Karen Etheridge Michael G. Schwern Mike Doherty particle
 
 =over 4
 
 =item *
 
+Dave Rolsky <autarch@urth.org>
+
+=item *
+
 Gabor Szabo <gabor@szabgab.com>
 
 =item *
@@ -467,7 +476,7 @@ Caleb Cushing <xenoterracide@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2015 by Caleb Cushing.
+This software is Copyright (c) 2016 by Caleb Cushing.
 
 This is free software, licensed under:
 
